##  Applying the TIME Classification
To determine the TIME classification, it is good to start by assessing the applications for Technical and Functional Fit. These aspects guide you in determining the suitability of each application and making informed decisions regarding its classification within the Gartner® TIME framework.
Technical Fit refers to the quality of your application; it answers if the application meets technical standards and if it fits into your architecture. This involves service levels, risk, maintainability, reliance on technical experts, information quality, and so on.
Functional Fit describes how well the application aligns with your business needs. It reflects how well the application supports business capabilities and processes. Rating each application as high or low for these two items indicates which of the four TIME classifications to apply to it.
![](https://help.sap.com/doc/72d375467c1e4dcb872dfa2998b6328d/CLOUD/en-US/loio27415d3d7a44101482eac89c210ad961_LowRes.gif)
The following matrix illustrates how you can determine the TIME classification of the application based on its Technical and Functional Fit.
![](https://help.sap.com/doc/72d375467c1e4dcb872dfa2998b6328d/CLOUD/en-US/loio2757b08e7a441014ace0f731021e939f_LowRes.png)
Assign ranks to each of your applications for Technical and Functional Fit, and you'll then be able to assign a TIME status to it as described here:
  * Applications with a high Technical Fit but low Functional Fit will be Tolerated.
  * Applications with a high Technical Fit and high Functional Fit will be Invested.
  * Applications with a low Technical Fit and high Functional Fit will be Migrated.
  * Applications with a low Technical Fit and low Functional Fit will be Eliminated.


TIME classification can be documented in the Application Fact Sheet under the Portfolio Strategy section.
  1. In the Portfolio Strategy section, hover over the TIME classification field to see the Edit button appear.
  2. Click on the Edit button on the right and choose the appropriate classification from the TIME classification drop-down menu and save.![](https://help.sap.com/doc/72d375467c1e4dcb872dfa2998b6328d/CLOUD/en-US/loio2754cdf47a441014bfdde42382fa7d6e_LowRes.gif)


You can also automate the process of assigning TIME classification values based on the functional and technical fit of applications. To learn how to configure this automation, see [Automations Best Practices](https://help.sap.com/docs/leanix/ea/automations-best-practices?locale=en-US&state=PRODUCTION&version=CLOUD "Examples and best practices for automations.") .
However, it is recommended that the final decision on how to deal with the application is not made solely on the basis of the assigned TIME classification but after consulting with different stakeholders who would be affected by the change.
